@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,8 +20,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_COMMON_H_
-#define __PAROLE_COMMON_H_
+#ifndef SRC_COMMON_PAROLE_COMMON_H_
+#define SRC_COMMON_PAROLE_COMMON_H_
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -45,4 +45,4 @@ void        parole_window_normal_cursor     (GdkWindow *window);
 
 
 
-#endif /* __PAROLE_COMMON_ */
+#endif /* SRC_COMMON_PAROLE_COMMON_H_ */
