@@ -1,7 +1,5 @@
 #include "gmarshal.h"
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,7 +47,6 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* VOID:STRING,STRING (gmarshal.list:1) */
 void
 _gmarshal_VOID__STRING_STRING (GClosure     *closure,
@@ -59,13 +56,13 @@ _gmarshal_VOID__STRING_STRING (GClosure     *closure,
                                gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  GMarshalFunc_VOID__STRING_STRING callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -96,14 +93,14 @@ _gmarshal_VOID__BOOLEAN_BOOLEAN_POINTER (GClosure     *closure,
                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                          gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__BOOLEAN_BOOLEAN_POINTER) (gpointer     data1,
-                                                              gboolean     arg_1,
-                                                              gboolean     arg_2,
-                                                              gpointer     arg_3,
-                                                              gpointer     data2);
-  GMarshalFunc_VOID__BOOLEAN_BOOLEAN_POINTER callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__BOOLEAN_BOOLEAN_POINTER) (gpointer data1,
+                                                              gboolean arg1,
+                                                              gboolean arg2,
+                                                              gpointer arg3,
+                                                              gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__BOOLEAN_BOOLEAN_POINTER callback;
 
   g_return_if_fail (n_param_values == 4);
 
