@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,15 +20,15 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_GST_H
-#define __PAROLE_GST_H
+#ifndef SRC_GST_PAROLE_GST_H_
+#define SRC_GST_PAROLE_GST_H_
 
 #include <glib-object.h>
 #include <gst/gst.h>
 #include <gtk/gtk.h>
 
-#include <src/misc/parole-stream.h>
-#include <src/misc/parole-enum-types.h>
+#include "src/misc/parole-enum-types.h"
+#include "src/misc/parole-stream.h"
 
 G_BEGIN_DECLS
 
@@ -36,19 +36,16 @@ G_BEGIN_DECLS
 #define PAROLE_GST(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), PAROLE_TYPE_GST, ParoleGst))
 #define PAROLE_IS_GST(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), PAROLE_TYPE_GST))
 
-typedef enum
-{
+typedef enum {
     PAROLE_ASPECT_RATIO_NONE,
     PAROLE_ASPECT_RATIO_AUTO,
     PAROLE_ASPECT_RATIO_SQUARE,
     PAROLE_ASPECT_RATIO_4_3,
     PAROLE_ASPECT_RATIO_16_9,
     PAROLE_ASPECT_RATIO_DVB
-
 } ParoleAspectRatio;
 
-enum
-{
+enum {
     GST_DVD_ROOT_MENU,
     GST_DVD_TITLE_MENU,
     GST_DVD_AUDIO_MENU,
@@ -58,15 +55,12 @@ enum
 
 typedef struct ParoleGstPrivate ParoleGstPrivate;
 
-typedef struct
-{
+typedef struct {
     GtkWidget           parent;
     ParoleGstPrivate   *priv;
-
 } ParoleGst;
 
-typedef struct
-{
+typedef struct {
     GtkWidgetClass  parent_class;
 
     void        (*media_state)              (ParoleGst *gst,
@@ -95,7 +89,6 @@ typedef struct
 
     void        (*dvd_chapter_count_change) (ParoleGst *gst,
                                              gint dvd_chapter_change);
-
 } ParoleGstClass;
 
 GType       parole_gst_get_type             (void) G_GNUC_CONST;
@@ -183,4 +176,4 @@ const ParoleStream
 
 G_END_DECLS
 
-#endif /* __PAROLE_GST_H */
+#endif /* SRC_GST_PAROLE_GST_H_ */
