@@ -1,7 +1,5 @@
 #include "parole-marshal.h"
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,7 +47,6 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* VOID:OBJECT,ENUM (parole-marshal.list:1) */
 void
 parole_marshal_VOID__OBJECT_ENUM (GClosure     *closure,
@@ -59,13 +56,13 @@ parole_marshal_VOID__OBJECT_ENUM (GClosure     *closure,
                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_ENUM) (gpointer     data1,
-                                                  gpointer     arg_1,
-                                                  gint         arg_2,
-                                                  gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_ENUM callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_ENUM) (gpointer data1,
+                                                  gpointer arg1,
+                                                  gint arg2,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_ENUM callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -96,13 +93,13 @@ parole_marshal_VOID__OBJECT_DOUBLE (GClosure     *closure,
                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_DOUBLE) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gdouble      arg_2,
-                                                    gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_DOUBLE callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_DOUBLE) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gdouble arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_DOUBLE callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -133,13 +130,13 @@ parole_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_INT) (gpointer     data1,
-                                                 gpointer     arg_1,
-                                                 gint         arg_2,
-                                                 gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_INT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_INT) (gpointer data1,
+                                                 gpointer arg1,
+                                                 gint arg2,
+                                                 gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_INT callback;
 
   g_return_if_fail (n_param_values == 3);
 
