@@ -230,9 +230,11 @@ void parole_conf_dialog_sink_plugin_changed_cb(GtkComboBox *widget,  ParoleConfD
 
 /* Change subtitle font */
 void parole_conf_dialog_font_set_cb(GtkFontButton *button, ParoleConfDialog *self) {
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     g_object_set(G_OBJECT(self->priv->conf),
-                  "subtitle-font", gtk_font_button_get_font_name(button),
-                  NULL);
+                 "subtitle-font", gtk_font_button_get_font_name(button),
+                 NULL);
+    G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 /* Finalize the dialog */
@@ -336,19 +338,22 @@ parole_conf_dialog_set_default_sink_plugin(ParoleConfDialog *self) {
                   "videosink", &sink_name,
                   NULL);
 
-    if (g_strcmp0(sink_name, "xvimagesink") == 0) {
+    if (g_strcmp0(sink_name, "autoimagesink") == 0) {
         gtk_combo_box_set_active(GTK_COMBO_BOX(self->priv->sink_combox), 0);
         return TRUE;
-    } else if (g_strcmp0(sink_name, "ximagesink") == 0) {
+    } else if (g_strcmp0(sink_name, "xvimagesink") == 0) {
         gtk_combo_box_set_active(GTK_COMBO_BOX(self->priv->sink_combox), 1);
         return TRUE;
+    } else if (g_strcmp0(sink_name, "ximagesink") == 0) {
+        gtk_combo_box_set_active(GTK_COMBO_BOX(self->priv->sink_combox), 2);
+        return TRUE;
     #ifdef HAVE_CLUTTER
     } else if (g_strcmp0(sink_name, "cluttersink") == 0) {
-        gtk_combo_box_set_active(GTK_COMBO_BOX(self->priv->sink_combox), 2);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(self->priv->sink_combox), 3);
         return TRUE;
     #endif
     } else {
-        gtk_combo_box_set_active(GTK_COMBO_BOX(self->priv->sink_combox), 1);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(self->priv->sink_combox), 0);
         return FALSE;
     }
 }
@@ -380,7 +385,9 @@ parole_conf_dialog_set_defaults(ParoleConfDialog *self) {
 
     parole_subtitle_encoding_set(GTK_COMBO_BOX(self->priv->encoding), subtitle_encoding);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gtk_font_button_set_font_name(GTK_FONT_BUTTON(self->priv->font_button), subtitle_font);
+    G_GNUC_END_IGNORE_DEPRECATIONS
 
     g_free(subtitle_font);
     g_free(subtitle_encoding);
