@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,13 +20,13 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_UTILS_H_
-#define __PAROLE_UTILS_H_
+#ifndef SRC_PAROLE_UTILS_H_
+#define SRC_PAROLE_UTILS_H_
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 
-#include <src/misc/parole-file.h>
+#include "src/misc/parole-file.h"
 
 gint        thunar_file_compare_by_name         (ParoleFile *file_a,
                                                  ParoleFile *file_b,
@@ -64,4 +64,4 @@ gboolean    g_simple_toggle_action_get_active   (GSimpleAction *simple);
 void        g_simple_toggle_action_set_active   (GSimpleAction *simple,
                                                  gboolean active);
 
-#endif /* __PAROLE_UTILS_ */
+#endif /* SRC_PAROLE_UTILS_H_ */
