@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,12 +20,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_VIS_H_
-#define __PAROLE_VIS_H_
+#ifndef SRC_PAROLE_VIS_H_
+#define SRC_PAROLE_VIS_H_
 
 #include <gst/gst.h>
 #include <glib.h>
 
 GHashTable        *parole_vis_get_plugins           (void);
 
-#endif /* __PAROLE_VIS_H_ */
+#endif /* SRC_PAROLE_VIS_H_ */
