@@ -719,12 +719,13 @@ state_changed_cb(ParoleProviderPlayer *player,
     parole_mpris_update_any(provider);
 }
 
+/*
 static void
 seeked_cb(ParoleProviderPlayer *player, Mpris2Provider *provider) {
     gint64 position = 0;
 
     if (NULL == provider->dbus_connection)
-        return; /* better safe than sorry */
+        return; // better safe than sorry
 
     position =(gint64) parole_provider_player_get_stream_position(provider->player);
 
@@ -732,6 +733,7 @@ seeked_cb(ParoleProviderPlayer *player, Mpris2Provider *provider) {
             "org.mpris.MediaPlayer2.Player", "Seeked",
             g_variant_new("(x)", position), NULL);
 }
+*/
 
 static void
 conf_changed_cb(ParoleConf *conf, GParamSpec *pspec, Mpris2Provider *provider) {
@@ -950,8 +952,10 @@ mpris2_provider_set_player(ParoleProviderPlugin *plugin, ParoleProviderPlayer *p
     g_signal_connect(player, "state_changed",
                       G_CALLBACK(state_changed_cb), plugin);
 
+/*
     g_signal_connect(player, "seeked",
                       G_CALLBACK(seeked_cb), plugin);
+*/
 
     provider->conf = parole_conf_new();
 
