@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2014 Simon Steinbeiß <ochosi@xfce.org>
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -24,63 +24,55 @@
 #include <config.h>
 #endif
 
-#include "sample-provider.h"
+#include "src/plugins/sample/sample-provider.h"
 
-static void   sample_provider_iface_init       (ParoleProviderPluginIface *iface);
-static void   sample_provider_finalize             (GObject                   *object);
+static void   sample_provider_iface_init(ParoleProviderPluginIface *iface);
+static void   sample_provider_finalize(GObject                     *object);
 
 
-struct _SampleProviderClass
-{
+struct _SampleProviderClass {
     GObjectClass parent_class;
 };
 
-struct _SampleProvider
-{
+struct _SampleProvider {
     GObject                 parent;
     ParoleProviderPlayer   *player;
 };
 
-PAROLE_DEFINE_TYPE_WITH_CODE   (SampleProvider, 
-                                sample_provider, 
-                                G_TYPE_OBJECT,
-                                PAROLE_IMPLEMENT_INTERFACE (PAROLE_TYPE_PROVIDER_PLUGIN, 
-                                sample_provider_iface_init));
-                              
-static gboolean sample_provider_is_configurable (ParoleProviderPlugin *plugin)
-{
+PAROLE_DEFINE_TYPE_WITH_CODE(SampleProvider,
+                             sample_provider,
+                             G_TYPE_OBJECT,
+                             PAROLE_IMPLEMENT_INTERFACE(PAROLE_TYPE_PROVIDER_PLUGIN,
+                             sample_provider_iface_init));
+
+static gboolean sample_provider_is_configurable(ParoleProviderPlugin *plugin) {
     return FALSE;
 }
 
 static void
-sample_provider_set_player (ParoleProviderPlugin *plugin, ParoleProviderPlayer *player)
-{
+sample_provider_set_player(ParoleProviderPlugin *plugin, ParoleProviderPlayer *player) {
     SampleProvider *provider;
-    provider = SAMPLE_PROVIDER (plugin);
-    
+    provider = SAMPLE_PROVIDER(plugin);
+
     provider->player = player;
 }
 
 static void
-sample_provider_iface_init (ParoleProviderPluginIface *iface)
-{
+sample_provider_iface_init(ParoleProviderPluginIface *iface) {
     iface->get_is_configurable = sample_provider_is_configurable;
     iface->set_player = sample_provider_set_player;
 }
 
-static void sample_provider_class_init (SampleProviderClass *klass)
-{
-    GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-    
+static void sample_provider_class_init(SampleProviderClass *klass) {
+    GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
+
     gobject_class->finalize = sample_provider_finalize;
 }
 
-static void sample_provider_init (SampleProvider *provider)
-{
+static void sample_provider_init(SampleProvider *provider) {
     provider->player = NULL;
 }
 
-static void sample_provider_finalize (GObject *object)
-{
-    G_OBJECT_CLASS (sample_provider_parent_class)->finalize (object);
+static void sample_provider_finalize(GObject *object) {
+    G_OBJECT_CLASS(sample_provider_parent_class)->finalize(object);
 }
